@@ -77,27 +77,31 @@ def rank_dataset(df_a,df_b,bf_representation='binary',bit_power=1,blk=[]):
       id1 = row['id1']
       id2 = row['id2']
 
-      bf1 = a[a.id == id1].values[0][1]
-      bf2 = b[b.id == id2].values[0][1]
+      try:
+        bf1 = a[a.id == id1].values[0][1]
+        bf2 = b[b.id == id2].values[0][1]
+        sim = jaccard_similarity(bf1,bf2,bf_representation=bf_representation)
 
-      sim = jaccard_similarity(bf1,bf2,bf_representation=bf_representation)
+        if bf_representation == 'binary':
+          bf1 = np.unpackbits(bf1)
+          bf2 = np.unpackbits(bf2)
 
-      if bf_representation == 'binary':
-        bf1 = np.unpackbits(bf1)
-        bf2 = np.unpackbits(bf2)
-
-        if bit_power!=1:
-          bf1 = bf1 * bit_power
-          bf2 = bf2 * bit_power
+          if bit_power!=1:
+            bf1 = bf1 * bit_power
+            bf2 = bf2 * bit_power
         
-      linha = [id1,id2,bf1,bf2,sim]
-      if id1 == id2:
-        # labels.append(np.array([1.]))
-        linha.append(1)
-      else:
-        # labels.append(np.array([0]))
-        linha.append(0)
-      ds.append(linha)
+        linha = [id1,id2,bf1,bf2,sim]
+
+        if id1 == id2:
+          # labels.append(np.array([1.]))
+          linha.append(1)
+        else:
+          # labels.append(np.array([0]))
+          linha.append(0)
+        
+        ds.append(linha)
+      except IndexError:
+        pass #quando o index nao e encontrado
     #fim do for
 
     df = pd.DataFrame(ds)      
